@@ -1,5 +1,5 @@
 import abc
-from typing import List, Optional, Set
+from typing import Dict, List, Optional, Set
 
 from auto_labeling_pipeline.label import Label
 
@@ -15,11 +15,10 @@ class Labels(metaclass=abc.ABCMeta):
         labels = [label for label in self.labels if not label.included(stop_labels)]
         return self.__class__(labels)
 
-    def replace_label(self, mapping: Optional[dict] = None) -> 'Labels':
+    def replace_label(self, mapping: Optional[Dict[str, str]] = None) -> 'Labels':
         if not mapping:
             return self
-        for label in self.labels:
-            label.replace(mapping)
+        self.labels = [label.replace(mapping) for label in self.labels]
         return self.__class__(self.labels)
 
     def dict(self) -> List[dict]:
@@ -39,5 +38,5 @@ class Seq2seqLabels(Labels):
     def filter_by_name(self, stop_labels: Optional[Set[str]] = None) -> Labels:
         return self
 
-    def replace_label(self, mapping: Optional[dict] = None) -> Labels:
+    def replace_label(self, mapping: Optional[Dict[str, str]] = None) -> Labels:
         return self
