@@ -1,12 +1,14 @@
 import abc
-from typing import Optional, Set
+from typing import Dict, Optional, Set
 
 from auto_labeling_pipeline.labels import Labels
 
 
 class BasePostProcessor(metaclass=abc.ABCMeta):
 
-    def __init__(self, stop_labels: Optional[Set[str]] = None, mapping: Optional[dict] = None):
+    def __init__(self,
+                 stop_labels: Optional[Set[str]] = None,
+                 mapping: Optional[Dict[str, str]] = None):
         self.stop_labels = stop_labels
         self.mapping = mapping
 
